#ifndef PACKET_MAKER_H
#define PACKET_MAKER_H

#include "Buffer.h"
#include "NetSender.h"
#include "nettypes.h"

class PacketMaker
{
protected:
	NetSender& sender;
	
public:
	PacketMaker(NetSender& sender) : sender(sender) {}
	
	Buffer makeARPRequest(const IPAddress& ip, const IPAddress& src) throw ();
	Buffer makeDHCPRequest() throw ();
};

// vim:set ts=4 sw=4:
#endif
